@@ -35,6 +35,8 @@ def cipher(message,key):
         ki = ki + 1
         oi = oi + 1
 
+        # print(ki)
+
         if ki + 1 == len(key):
             ki = 0
         if oi > 1:
@@ -49,7 +51,7 @@ def cipher(message,key):
         x.append(letter)
 
     message = "".join(x)
-    return str(y) + str(message)
+    return str(message)
 
 
 def decipher(code,key):
@@ -59,11 +61,7 @@ def decipher(code,key):
     if len(key) != 50:
         raise InvalidCode("Key received was corrupted.")
 
-    if str(code[0]) != "0" and str(code[0]) != "1":
-        raise InvalidCode("Code received was corrupted.")
-
     y = code[0]
-    code = code[1:]
     origin = code
     code = findall("...",code)
 
